CREATE TABLE IF NOT EXISTS 'config' (
                                _id INTEGER PRIMARY KEY AUTOINCREMENT,
                                version INTEGER NOT NULL UNIQUE ON CONFLICT REPLACE,
                                environment TEXT,
                                max_age TEXT
);

CREATE TABLE IF NOT EXISTS 'catch_up_metadata' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                                feed_id TEXT NOT NULL,
                                programme_id TEXT NOT NULL,
                                catch_up_date_time TEXT NOT NULL,
                                transmission_channel TEXT NOT NULL,
                                UNIQUE (feed_id, programme_id, catch_up_date_time) ON CONFLICT REPLACE
);

CREATE TABLE IF NOT EXISTS 'short' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                                short_title TEXT NOT NULL,
                                short_summary TEXT NOT NULL,
                                external_video_id TEXT NOT NULL,
                                series_number INTEGER NOT NULL,
                                episode_number INTEGER NOT NULL,
                                short_image_url TEXT NOT NULL,
                                short_type TEXT NOT NULL,
                                short_duration TEXT NOT NULL,
                                source_page TEXT NOT NULL,
                                guidance_message TEXT,
                                age_rating TEXT DEFAULT "0",
                                UNIQUE (source_page, external_video_id) ON CONFLICT REPLACE
);

CREATE TABLE IF NOT EXISTS 'series' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                                brand_title TEXT NOT NULL,
                                brand_encoded_title TEXT NOT NULL,
                                synopsis TEXT,
                                series_number INTEGER NOT NULL,
                                episodes_source_url TEXT NOT NULL,
                                clips_source_url TEXT NOT NULL,
                                parent_recommendations_source_url TEXT NOT NULL,
                                parent_clips_source_url TEXT NOT NULL,
                                parent_programme_type TEXT NOT NULL,
                                programme_type TEXT NOT NULL,
                                brand_channel TEXT NOT NULL,
                                UNIQUE (brand_encoded_title, series_number) ON CONFLICT REPLACE
);

CREATE TABLE IF NOT EXISTS 'page' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                                source_page TEXT NOT NULL,
                                next_page_url TEXT NOT NULL,
                                UNIQUE (source_page) ON CONFLICT REPLACE
);

CREATE TABLE IF NOT EXISTS 'recommendation' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                                brand_title TEXT NOT NULL,
                                brand_encoded_title TEXT NOT NULL,
                                brand_series_count INTEGER NOT NULL,
                                brand_episode_count INTEGER NOT NULL,
                                brand_image_url TEXT NOT NULL,
                                brand_summary TEXT NOT NULL,
                                source_page TEXT NOT NULL,
                                UNIQUE (source_page, brand_title) ON CONFLICT REPLACE
);

CREATE TABLE IF NOT EXISTS 'episode' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                                title TEXT NOT NULL,
                                summary TEXT NOT NULL,
                                episode_number INTEGER NOT NULL,
                                series_number INTEGER NOT NULL,
                                transmission_date TEXT NOT NULL,
                                programme_id TEXT NOT NULL,
                                delivery_download_url TEXT,
                                delivery_stream_url TEXT,
                                delivery_download_availability_start_date_time TEXT,
                                delivery_stream_availability_start_date_time TEXT,
                                delivery_download_availability_end_date_time TEXT,
                                delivery_stream_availability_end_date_time TEXT,
                                brand_encoded_title TEXT NOT NULL,
                                brand_title TEXT NOT NULL,
                                thumbnail_url TEXT NOT NULL,
                                duration TEXT NOT NULL,
                                short_synopsis TEXT,
                                request_type TEXT,
                                guidance_message TEXT,
                                programme_type TEXT,
                                first_transmission_channel TEXT NOT NULL,
                                age_rating TEXT DEFAULT "0",
                                premiere INTEGER NOT NULL,
                                UNIQUE (programme_id) ON CONFLICT REPLACE
);

CREATE TABLE IF NOT EXISTS 'search_result' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                                brand_title TEXT NOT NULL,
                                brand_encoded_title TEXT NOT NULL,
                                search_query TEXT NOT NULL,
                                search_unique_key TEXT UNIQUE ON CONFLICT REPLACE NOT NULL
);

CREATE TABLE IF NOT EXISTS 'category' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                                category_id TEXT NOT NULL,
                                category_title TEXT NOT NULL,
                                category_transmission_date_link TEXT NOT NULL,
                                UNIQUE (category_id, category_title) ON CONFLICT REPLACE
);

CREATE TABLE IF NOT EXISTS 'brand' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                                brand_id TEXT UNIQUE ON CONFLICT REPLACE NOT NULL,
                                brand_title TEXT NOT NULL,
                                brand_encoded_title TEXT NOT NULL,
                                brand_image_url TEXT NOT NULL,
                                brand_sort_letter TEXT NOT NULL,
                                brand_series_count INTEGER NOT NULL,
                                brand_programme_count INTEGER NOT NULL,
                                brand_channel TEXT NOT NULL,
                                brand_summary TEXT NOT NULL
);

CREATE TABLE IF NOT EXISTS 'atoz_brands' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                                source_page TEXT NOT NULL,
                                sort_letter TEXT NOT NULL,
                                atoz_brands_brand_id TEXT NOT NULL,
                                UNIQUE (atoz_brands_brand_id) ON CONFLICT REPLACE
);

CREATE TABLE IF NOT EXISTS 'categories_brands' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                                source_page TEXT NOT NULL,
                                categories_brands_category_id TEXT NOT NULL,
                                categories_brands_brand_id TEXT NOT NULL,
                                FOREIGN KEY (categories_brands_brand_id) REFERENCES brand(brand_id) ON DELETE CASCADE,
                                FOREIGN KEY (categories_brands_category_id) REFERENCES category(category_id) ON DELETE CASCADE,
                                UNIQUE (categories_brands_category_id, categories_brands_brand_id) ON CONFLICT REPLACE
);

CREATE TABLE IF NOT EXISTS 'download_metadata' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                                download_metadata_programme_id TEXT NOT NULL,
                                download_metadata_duration INTEGER NOT NULL,
                                download_batch_id INTEGER NOT NULL,
                                UNIQUE (download_metadata_programme_id) ON CONFLICT REPLACE
);

CREATE TABLE IF NOT EXISTS 'advert' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                                advert_id TEXT NOT NULL,
                                advert_download_batch_id INTEGER,
                                advert_download_duration INTEGER NOT NULL,
                                advert_impression_urls TEXT,
                                advert_click_urls TEXT,
                                UNIQUE (advert_id, advert_download_batch_id) ON CONFLICT REPLACE
);

CREATE TABLE IF NOT EXISTS 'advert_slot' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                                advert_slot_id TEXT NOT NULL,
                                advert_slot_download_metadata_id TEXT NOT NULL,
                                advert_slot_time_position DOUBLE NOT NULL,
                                advert_slot_time_position_class TEXT NOT NULL,
                                FOREIGN KEY (advert_slot_download_metadata_id) REFERENCES download_metadata(download_metadata_programme_id) ON DELETE CASCADE,
                                UNIQUE (advert_slot_id) ON CONFLICT REPLACE

);

CREATE TABLE IF NOT EXISTS 'advert_slot_entry' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                                advert_slot_id TEXT NOT NULL,
                                advert_id TEXT NOT NULL,
                                advert_slot_entry_position INTEGER,
                                FOREIGN KEY (advert_slot_id) REFERENCES advert_slot(advert_slot_id) ON DELETE CASCADE,
                                FOREIGN KEY (advert_id) REFERENCES advert(advert_id) ON DELETE CASCADE,
                                UNIQUE (advert_slot_id, advert_id, advert_slot_entry_position) ON CONFLICT REPLACE
);

CREATE TABLE IF NOT EXISTS 'watch_live_availability_items' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                                distribution TEXT NOT NULL,
                                start_date_time TEXT NOT NULL,
                                end_date_time TEXT NOT NULL,
                                title TEXT NOT NULL,
                                SUMMARY TEXT NOT NULL,
                                SIMULCAST_URL TEXT NOT NULL,
                                UNIQUE (distribution, title, start_date_time) ON CONFLICT REPLACE
);

CREATE TABLE IF NOT EXISTS 'box_set' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                                collection_title TEXT NOT NULL,
                                collection_subtitle TEXT,
                                title TEXT NOT NULL,
                                encoded_title TEXT NOT NULL,
                                subtitle TEXT NOT NULL,
                                synopsis TEXT NOT NULL,
                                sponsored_url TEXT NOT NULL,
                                UNIQUE (title, encoded_title) ON CONFLICT REPLACE
);

CREATE TABLE IF NOT EXISTS 'recommends_collections' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                                collection_id TEXT NOT NULL,
                                collection_title TEXT NOT NULL,
                                collection_subtitle TEXT,
                                brand_id TEXT NOT NULL,
                                brand_title TEXT NOT NULL,
                                brand_encoded_title TEXT NOT NULL,
                                brand_summary TEXT NOT NULL,
                                brand_image_url TEXT NOT NULL,
                                brand_subtitle TEXT,
                                is_episode INTEGER NOT NULL DEFAULT 0,
                                episode_number INTEGER NOT NULL DEFAULT 0,
                                series_number INTEGER NOT NULL DEFAULT 0,
                                programme_id TEXT,
                                transmission_channel TEXT,
                                programme_type TEXT,
                                UNIQUE (collection_id, brand_id) ON CONFLICT REPLACE
);

CREATE TABLE IF NOT EXISTS 'recommends_shorts' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                                collection_id TEXT NOT NULL,
                                collection_title TEXT NOT NULL,
                                collection_subtitle TEXT NOT NULL,
                                programme_id TEXT NOT NULL,
                                FOREIGN KEY (programme_id) REFERENCES episode(programme_id) ON DELETE CASCADE,
                                UNIQUE (programme_id) ON CONFLICT REPLACE
);

CREATE TABLE IF NOT EXISTS 'asset_information_video' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                                delivery_stream_url TEXT NOT NULL,
                                guidance_message TEXT,
                                programme_id TEXT NOT NULL,
                                brand_title TEXT NOT NULL,
                                brand_encoded_title TEXT NOT NULL,
                                seconds_since_broadcast INTEGER,
                                request_type TEXT NOT NULL,
                                episode_title TEXT NOT NULL,
                                contract_id TEXT NOT NULL,
                                episode_id INTEGER NOT NULL,
                                audio_described INTEGER NOT NULL,
                                UNIQUE (programme_id) ON CONFLICT REPLACE
);

CREATE VIEW IF NOT EXISTS "episodes_with_catch_up_metadata" AS
                                SELECT DISTINCT
                                    episode._id as episode_db_id,
                                    episode.title,
                                    episode.summary,
                                    episode.episode_number,
                                    episode.series_number,
                                    episode.programme_id,
                                    episode.delivery_download_url,
                                    episode.delivery_stream_url,
                                    episode.delivery_download_availability_start_date_time,
                                    episode.delivery_stream_availability_start_date_time,
                                    episode.delivery_download_availability_end_date_time,
                                    episode.delivery_stream_availability_end_date_time,
                                    episode.brand_encoded_title,
                                    episode.brand_title,
                                    episode.transmission_date,
                                    episode.thumbnail_url,
                                    episode.duration,
                                    episode.short_synopsis,
                                    episode.request_type,
                                    episode.guidance_message,
                                    episode.programme_type,
                                    episode.age_rating,
                                    episode.first_transmission_channel,
                                    episode.premiere,
                                    catch_up_metadata.transmission_channel,
                                    catch_up_metadata.catch_up_date_time,
                                    catch_up_metadata._id as feed_id_order
                                FROM episode
                                LEFT OUTER JOIN
                                    catch_up_metadata ON episode.programme_id = catch_up_metadata.programme_id;

CREATE VIEW IF NOT EXISTS "asset_info_with_episodes" AS
                                SELECT DISTINCT
                                    asset_information_video._id,
                                    asset_information_video.programme_id,
                                    asset_information_video.seconds_since_broadcast,
                                    asset_information_video.request_type,
                                    asset_information_video.episode_title,
                                    asset_information_video.contract_id,
                                    asset_information_video.episode_id,
                                    asset_information_video.brand_title,
                                    asset_information_video.brand_encoded_title,
                                    asset_information_video.audio_described,
                                    asset_information_video.delivery_stream_url,
                                    asset_information_video.guidance_message,
                                    episode._id as episode_db_id,
                                    episode.series_number,
                                    episode.episode_number,
                                    episode.first_transmission_channel,
                                    episode.programme_type,
                                    episode.premiere
                                FROM asset_information_video
                                LEFT OUTER JOIN
                                    episode ON asset_information_video.programme_id = episode.programme_id;

CREATE VIEW IF NOT EXISTS "episodes_by_downloads_metadata" AS
                                SELECT DISTINCT
                                    episode._id as episode_db_id,
                                    episode.title,
                                    episode.summary,
                                    episode.episode_number,
                                    episode.series_number,
                                    episode.programme_id,
                                    episode.delivery_download_url,
                                    episode.delivery_stream_url,
                                    episode.delivery_download_availability_start_date_time,
                                    episode.delivery_stream_availability_start_date_time,
                                    episode.delivery_download_availability_end_date_time,
                                    episode.delivery_stream_availability_end_date_time,
                                    episode.brand_encoded_title,
                                    episode.brand_title,
                                    episode.transmission_date,
                                    episode.thumbnail_url,
                                    episode.duration,
                                    episode.short_synopsis,
                                    episode.request_type,
                                    episode.guidance_message,
                                    episode.programme_type,
                                    episode.age_rating,
                                    episode.first_transmission_channel,
                                    episode.premiere,
                                    download_metadata.download_batch_id
                                FROM episode
                                LEFT OUTER JOIN
                                    download_metadata ON episode.programme_id = download_metadata.download_metadata_programme_id;

CREATE VIEW IF NOT EXISTS "brands_by_letter" AS
                                SELECT DISTINCT
                                    brand._id,
                                    brand.brand_id as brand_id,
                                    brand.brand_title as brand_title,
                                    brand.brand_encoded_title as brand_encoded_title,
                                    brand.brand_image_url as brand_image_url,
                                    brand.brand_sort_letter as brand_sort_letter,
                                    brand.brand_series_count as brand_series_count,
                                    brand.brand_programme_count as brand_programme_count,
                                    brand.brand_channel as brand_channel,
                                    brand.brand_summary as brand_summary,
                                    atoz_brands._id as atoz_id,
                                    atoz_brands.source_page,
                                    atoz_brands.sort_letter,
                                    atoz_brands.atoz_brands_brand_id
                                FROM brand
                                LEFT OUTER JOIN
                                    atoz_brands ON brand.brand_id = atoz_brands.atoz_brands_brand_id;

CREATE VIEW IF NOT EXISTS "brands_by_category" AS
                                SELECT DISTINCT
                                    category.category_id as category_id,
                                    categories_brands._id as brand_order,
                                    brand.brand_id as brand_id,
                                    brand.brand_title as brand_title,
                                    brand.brand_encoded_title as brand_encoded_title,
                                    brand.brand_image_url as brand_image_url,
                                    brand.brand_sort_letter as brand_sort_letter,
                                    brand.brand_series_count as brand_series_count,
                                    brand.brand_programme_count as brand_programme_count,
                                    brand.brand_channel as brand_channel,
                                    brand.brand_summary as brand_summary,
                                    categories_brands.source_page
                                FROM brand
                                LEFT OUTER JOIN
                                    categories_brands ON brand.brand_id = categories_brands.categories_brands_brand_id
                                LEFT OUTER JOIN
                                    category ON categories_brands.categories_brands_category_id = category.category_id;

CREATE VIEW IF NOT EXISTS "advert_slot_entry_with_advert" AS
                                SELECT DISTINCT
                                    advert_slot.advert_slot_time_position,
                                    advert_slot.advert_slot_time_position_class,
                                    advert_slot.advert_slot_download_metadata_id,
                                    advert_slot_entry.advert_slot_id,
                                    advert_slot_entry.advert_id,
                                    advert_slot_entry.advert_slot_entry_position,
                                    advert.advert_download_batch_id,
                                    advert.advert_impression_urls,
                                    advert.advert_click_urls,
                                    advert.advert_download_duration
                                FROM advert
                                INNER JOIN
                                    advert_slot_entry ON advert_slot_entry.advert_id = advert.advert_id
                                INNER JOIN
                                    advert_slot ON advert_slot.advert_slot_id = advert_slot_entry.advert_slot_id
                                INNER JOIN
                                    download_metadata ON download_metadata.download_metadata_programme_id = advert_slot.advert_slot_download_metadata_id
                                        AND download_metadata.download_batch_id = advert.advert_download_batch_id
                                ORDER BY advert_slot.advert_slot_download_metadata_id ASC,
                                    advert_slot.advert_slot_time_position ASC,
                                    advert_slot_entry.advert_slot_entry_position ASC;

CREATE VIEW IF NOT EXISTS 'recommends_shorts_with_episodes' AS
                                SELECT DISTINCT
                                    episode.title,
                                    episode.summary,
                                    episode.episode_number,
                                    episode.series_number,
                                    episode.programme_id,
                                    episode.delivery_download_url,
                                    episode.delivery_stream_url,
                                    episode.delivery_download_availability_start_date_time,
                                    episode.delivery_stream_availability_start_date_time,
                                    episode.delivery_download_availability_end_date_time,
                                    episode.delivery_stream_availability_end_date_time,
                                    episode.brand_encoded_title,
                                    episode.brand_title,
                                    episode.transmission_date,
                                    episode.thumbnail_url,
                                    episode.duration,
                                    episode.short_synopsis,
                                    episode.request_type,
                                    episode.guidance_message,
                                    episode.programme_type,
                                    episode.age_rating,
                                    episode.first_transmission_channel,
                                    episode.premiere,
                                    recommends_shorts.collection_id,
                                    recommends_shorts.collection_title,
                                    recommends_shorts.collection_subtitle
                                FROM episode
                                INNER JOIN
                                    recommends_shorts ON episode.programme_id = recommends_shorts.programme_id;

CREATE TABLE IF NOT EXISTS 'recommends_modules' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                               module_title TEXT NOT NULL,
                               module_url TEXT NOT NULL,
                               module_id TEXT NOT NULL,
                               UNIQUE (module_id) ON CONFLICT REPLACE
);
