CREATE TABLE 'promotions' (
    _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
    uuid TEXT NOT NULL,
    link TEXT NOT NULL,
    phone_image_path TEXT NOT NULL,
    phone_image_width INTEGER NOT NULL,
    phone_image_height INTEGER NOT NULL,
    tablet_image_path TEXT NOT NULL,
    tablet_image_width INTEGER NOT NULL,
    tablet_image_height INTEGER NOT NULL,
    start_date INTEGER NOT NULL,
    end_date INTEGER NOT NULL,
    accessible_copy TEXT NOT NULL
);

CREATE UNIQUE INDEX 'promotions_uuid' ON promotions(uuid);

CREATE TABLE 'brand_promotions' (
    _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
    websafetitle TEXT NOT NULL,
    item_position INTEGER NOT NULL,
    promotion_uuid TEXT NOT NULL       -- FK to the promotions table's UUID field
);

CREATE INDEX 'brand_promotions_websafetitle' ON brand_promotions(websafetitle);
CREATE INDEX 'brand_promotions_promotion_uuid' ON brand_promotions(promotion_uuid);

CREATE TABLE 'screen_promotions' (
    _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
    screen_key TEXT NOT NULL,             -- Currently only supports "watch_live"
    promotion_uuid TEXT NOT NULL          -- FK to the promotions table UUID field
);

CREATE INDEX 'screen_promotions_screen_key' ON screen_promotions(screen_key);
CREATE INDEX 'screen_promotions_promotion_uuid' ON screen_promotions(promotion_uuid);

CREATE VIEW 'promotions_for_brands' AS
SELECT promotions.*, brand_promotions.websafetitle, brand_promotions.item_position
FROM promotions INNER JOIN brand_promotions ON
promotions.uuid = brand_promotions.promotion_uuid;

CREATE VIEW 'promotions_for_screens' AS
SELECT promotions.*, screen_promotions.screen_key
FROM promotions INNER JOIN screen_promotions ON
promotions.uuid = screen_promotions.promotion_uuid;


-- Fix bug with ordering in My4 views (shouldn't be on the views themselves!)

DROP VIEW 'my4_watching_with_episode';

CREATE VIEW 'my4_watching_with_episode' AS
SELECT
    brand_hub_episodes.*,
    my4_watching.episode_id,
    my4_watching.brand_id,
    my4_watching.new_series,
    my4_watching.new_episode,
    my4_watching.item_position
FROM brand_hub_episodes INNER JOIN my4_watching
ON brand_hub_episodes.programme_id = my4_watching.episode_id;

DROP VIEW 'my4_history_with_episode';

CREATE VIEW 'my4_history_with_episode' AS
SELECT
    brand_hub_episodes.*,
    my4_history.episode_id,
    my4_history.brand_id,
    my4_history.new_series,
    my4_history.new_episode,
    my4_history.item_position
FROM brand_hub_episodes INNER JOIN my4_history
ON brand_hub_episodes.programme_id = my4_history.episode_id;
