CREATE TABLE IF NOT EXISTS 'persisted_download_request' (
    _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
    programme_id TEXT NOT NULL,
    download_batch_id TEXT NOT NULL,
    contents TEXT NOT NULL,
    UNIQUE (programme_id) ON CONFLICT REPLACE
    UNIQUE (download_batch_id) ON CONFLICT REPLACE
);

CREATE INDEX persisted_download_request_programme_id_index ON persisted_download_request(programme_id);
CREATE INDEX persisted_download_request_download_batch_id_index ON persisted_download_request(download_batch_id);

CREATE VIEW IF NOT EXISTS "download_batch_id_by_programme_id" AS
    SELECT programme_id, download_batch_id FROM persisted_download_request
    UNION
    SELECT download_metadata_programme_id AS programme_id, download_batch_id FROM download_metadata;

DROP VIEW "advert_slot_entry_with_advert";
CREATE VIEW IF NOT EXISTS "advert_slot_entry_with_advert" AS
    SELECT DISTINCT
        advert_slot.advert_slot_time_position,
        advert_slot.advert_slot_time_position_class,
        advert_slot.advert_slot_download_metadata_id,
        advert_slot_entry.advert_slot_id,
        advert_slot_entry.advert_id,
        advert_slot_entry.advert_slot_entry_position,
        advert.creative_id,
        advert.advert_download_batch_id,
        advert.advert_impression_urls,
        advert.advert_click_urls,
        advert.advert_download_duration
    FROM advert
    INNER JOIN
        advert_slot_entry ON advert_slot_entry.advert_id = advert.advert_id
    INNER JOIN
        advert_slot ON advert_slot.advert_slot_id = advert_slot_entry.advert_slot_id
    INNER JOIN
        download_batch_id_by_programme_id ON download_batch_id_by_programme_id.programme_id = advert_slot.advert_slot_download_metadata_id
            AND download_batch_id_by_programme_id.download_batch_id = advert.advert_download_batch_id
    ORDER BY advert_slot.advert_slot_download_metadata_id ASC,
        advert_slot.advert_slot_time_position ASC,
        advert_slot_entry.advert_slot_entry_position ASC;
