DROP TABLE IF EXISTS 'brand';

CREATE TABLE 'brand' (
                                _id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                                brand_id TEXT UNIQUE ON CONFLICT REPLACE NOT NULL,
                                brand_title TEXT NOT NULL,
                                brand_encoded_title TEXT NOT NULL,
                                brand_image_url TEXT NOT NULL,
                                brand_sort_letter TEXT NOT NULL,
                                brand_series_count INTEGER NOT NULL,
                                brand_programme_count INTEGER NOT NULL,
                                brand_channel TEXT NOT NULL,
                                brand_summary TEXT NOT NULL,
                                brand_programme_type TEXT NOT NULL
);

DROP VIEW IF EXISTS 'brands_by_category';

CREATE VIEW 'brands_by_category' AS
                                SELECT DISTINCT
                                    category.category_id as category_id,
                                    categories_brands._id as brand_order,
                                    brand.brand_id as brand_id,
                                    brand.brand_title as brand_title,
                                    brand.brand_encoded_title as brand_encoded_title,
                                    brand.brand_image_url as brand_image_url,
                                    brand.brand_sort_letter as brand_sort_letter,
                                    brand.brand_series_count as brand_series_count,
                                    brand.brand_programme_count as brand_programme_count,
                                    brand.brand_channel as brand_channel,
                                    brand.brand_summary as brand_summary,
                                    brand.brand_programme_type as brand_programme_type,
                                    categories_brands.source_page
                                FROM brand
                                LEFT OUTER JOIN
                                    categories_brands ON brand.brand_id = categories_brands.categories_brands_brand_id
                                LEFT OUTER JOIN
                                    category ON categories_brands.categories_brands_category_id = category.category_id;

DROP VIEW IF EXISTS 'brands_by_letter';

CREATE VIEW 'brands_by_letter' AS
                                SELECT DISTINCT
                                    brand._id,
                                    brand.brand_id as brand_id,
                                    brand.brand_title as brand_title,
                                    brand.brand_encoded_title as brand_encoded_title,
                                    brand.brand_image_url as brand_image_url,
                                    brand.brand_sort_letter as brand_sort_letter,
                                    brand.brand_series_count as brand_series_count,
                                    brand.brand_programme_count as brand_programme_count,
                                    brand.brand_channel as brand_channel,
                                    brand.brand_summary as brand_summary,
                                    brand.brand_programme_type as brand_programme_type,
                                    atoz_brands._id as atoz_id,
                                    atoz_brands.source_page,
                                    atoz_brands.sort_letter,
                                    atoz_brands.atoz_brands_brand_id
                                FROM brand
                                LEFT OUTER JOIN
                                    atoz_brands ON brand.brand_id = atoz_brands.atoz_brands_brand_id;
